<?php
/*
* 2007-2012 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2012 PrestaShop SA
*  @version  Release: $Revision: 7048 $
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_'))
	exit;

class yp_SlickSlider extends Module
{
	private $_html = '';
	private $_postErrors = array();
	
	protected static $cache_products;

	function __construct()
	{
		$this->name = 'yp_slickslider';
		$this->tab = 'front_office_features';
		$this->version = '1.0';
		$this -> author = 'YOPIXEL.COM';
		$this->need_instance = 0;
		$this->bootstrap = true;

		parent::__construct();

		$this->displayName = $this->l('Featured Products with Slick Slider');
		$this->description = $this->l('Displays Featured Products in the middle of your homepage with Slick slider.');
	}

	function install()
	{
		$this->_clearCache('*');
		if (!Configuration::updateValue('HOME_FEATURED_SLICK_SLIDER_NBR', 8) || !parent::install() || !$this->registerHook('displayTop') || !$this->registerHook('displayFooter' ) || !$this->registerHook('displayHeader' )
			|| !$this->registerHook('addproduct')
			|| !$this->registerHook('updateproduct')
			|| !$this->registerHook('deleteproduct')
			)
			return false;
		return true;
	}
	
	public function uninstall()
	{
		$this->_clearCache('*');

		return parent::uninstall();
	}

	public function getContent()
	{
		$output = '';
		$errors = array();
		if (Tools::isSubmit('submitYP_SlickSlider'))
		{
			$nbr = Tools::getValue('HOME_FEATURED_SLICK_SLIDER_NBR');
			if (!Validate::isInt($nbr) || $nbr <= 0)
			$errors[] = $this->l('The number of products is invalid. Please enter a positive number.');

			$cat = Tools::getValue('HOME_FEATURED_SLICK_SLIDER_CAT');
			if (!Validate::isInt($cat) || $cat <= 0)
				$errors[] = $this->l('The category ID is invalid. Please choose an existing category ID.');

			$rand = Tools::getValue('HOME_FEATURED_SLICK_SLIDER_RANDOMIZE');
			if (!Validate::isBool($rand))
				$errors[] = $this->l('Invalid value for the "randomize" flag.');
			if (isset($errors) && count($errors))
				$output = $this->displayError(implode('<br />', $errors));
			else
			{
				Configuration::updateValue('HOME_FEATURED_SLICK_SLIDER_NBR', (int)$nbr);
				Configuration::updateValue('HOME_FEATURED_SLICK_SLIDER_CAT', (int)$cat);
				Configuration::updateValue('HOME_FEATURED_SLICK_SLIDER_RANDOMIZE', (bool)$rand);
				Tools::clearCache(Context::getContext()->smarty, $this->getTemplatePath('slickslider.tpl'));
				$output = $this->displayConfirmation($this->l('Your settings have been updated.'));
			}
		}
		
		$output .= '<p style="with:100%;text-align:center;color:darkred;">In case of problems, contact : <a href="https:www.yopixel.com/prestashop/fr" target="_blank"><i class="icon-external-link"></i> www.yopixel.com</a></p>';
		return $output.$this->renderForm();
	}
	
	
	public function _cacheProducts()
	{
		if (!isset(yp_SlickSlider::$cache_products))
		{
			$category = new Category((int)Configuration::get('HOME_FEATURED_SLICK_SLIDER_CAT'), (int)Context::getContext()->language->id);
			$nb = (int)Configuration::get('HOME_FEATURED_SLICK_SLIDER_NBR');
			if (Configuration::get('HOME_FEATURED_SLICK_SLIDER_RANDOMIZE'))
				yp_SlickSlider::$cache_products = $category->getProducts((int)Context::getContext()->language->id, 1, ($nb ? $nb : 8), null, null, false, true, true, ($nb ? $nb : 8));
			else
				yp_SlickSlider::$cache_products = $category->getProducts((int)Context::getContext()->language->id, 1, ($nb ? $nb : 8), 'position');
		}

		if (yp_SlickSlider::$cache_products === false || empty(yp_SlickSlider::$cache_products))
			return false;
	}
	
	public function hookUpdateProduct($params)
	{
		$this->_clearCache('*');
	}

	public function hookDeleteProduct($params)
	{
		$this->_clearCache('*');
	}

	public function hookCategoryUpdate($params)
	{
		$this->_clearCache('*');
	}

	public function _clearCache($template, $cache_id = NULL, $compile_id = NULL)
	{
		parent::_clearCache('slickslider.tpl');
		//parent::_clearCache('tab.tpl', 'homefeatured-tab');
	}
	
	public function renderForm()
	{
		$fields_form = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Settings'),
					'icon' => 'icon-cogs'
				),
				'description' => $this->l('To add products to your homepage, simply add them to the corresponding product category (default: "Home").'),
				'input' => array(
					array(
						'type' => 'text',
						'label' => $this->l('Number of products to be displayed'),
						'name' => 'HOME_FEATURED_SLICK_SLIDER_NBR',
						'class' => 'fixed-width-xs',
						'desc' => $this->l('Set the number of products that you would like to display on homepage (default: 8).'),
					),
					array(
						'type' => 'text',
						'label' => $this->l('Category from which to pick products to be displayed'),
						'name' => 'HOME_FEATURED_SLICK_SLIDER_CAT',
						'class' => 'fixed-width-xs',
						'desc' => $this->l('Choose the category ID of the products that you would like to display on homepage (default: 2 for "Home").'),
					),
					array(
						'type' => 'switch',
						'label' => $this->l('Randomly display featured products'),
						'name' => 'HOME_FEATURED_SLICK_SLIDER_RANDOMIZE',
						'class' => 'fixed-width-xs',
						'desc' => $this->l('Enable if you wish the products to be displayed randomly (default: no).'),
						'values' => array(
							array(
								'id' => 'active_on',
								'value' => 1,
								'label' => $this->l('Yes')
							),
							array(
								'id' => 'active_off',
								'value' => 0,
								'label' => $this->l('No')
							)
						),
					),
					
				),
				'submit' => array(
					'title' => $this->l('Save'),
				)
			),
		);
		
		$helper = new HelperForm();
		$helper->show_toolbar = false;
		$helper->table =  $this->table;
		$lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->default_form_language = $lang->id;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
		$this->fields_form = array();

		$helper->identifier = $this->identifier;
		//$helper->submit_action = 'submitModule';
		$helper->submit_action = 'submitYP_SlickSlider';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->tpl_vars = array(
			'fields_value' => $this->getConfigFieldsValues(),
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id
		);

		return $helper->generateForm(array($fields_form));
	}
	
	
	public function getConfigFieldsValues()
	{
		return array(
			'HOME_FEATURED_SLICK_SLIDER_NBR' => Tools::getValue('HOME_FEATURED_SLICK_SLIDER_NBR', (int)Configuration::get('HOME_FEATURED_SLICK_SLIDER_NBR')),
			'HOME_FEATURED_SLICK_SLIDER_CAT' => Tools::getValue('HOME_FEATURED_SLICK_SLIDER_CAT', (int)Configuration::get('HOME_FEATURED_SLICK_SLIDER_CAT')),
			'HOME_FEATURED_SLICK_SLIDER_RANDOMIZE' => Tools::getValue('HOME_FEATURED_SLICK_SLIDER_RANDOMIZE', (bool)Configuration::get('HOME_FEATURED_SLICK_SLIDER_RANDOMIZE')),
		);
	}

	public function hookDisplayFooter($params)
	{

	}
	
	public function hookDisplayHeader($params)
	{
	
	}

	public function hookDisplayHome($params)
	{
		
		
		if (!$this->isCached('slickslider.tpl', $this->getCacheId()))
		{
			$this->_cacheProducts();
			$this->smarty->assign(
				array(
					'products_ss' => yp_SlickSlider::$cache_products,
					'add_prod_display' => Configuration::get('PS_ATTRIBUTE_CATEGORY_DISPLAY'),
					'homeSize' => Image::getSize(ImageType::getFormatedName('home')),
				)
			);
		}
		
		$this->context->controller->addCss($this->_path.'css/front/slickslider.css');
		$this->context->controller->addJS($this->_path.'js/front/slickslider.js');
	
		return $this->display(__FILE__, 'slickslider.tpl', $this->getCacheId());
	}
	
	public function hookDisplayTop($param)
    {

		return $this->hookDisplayHome($params);
		
	}

}
